/*
 * extract.c
 *
 * This file contains the main() function of a program for extracting
 * compressed data from a ZIP-archive. Gratefully received from a person who
 * wishes to remain anonymous.
 * Slightly modified by Peter Conrad, Aug '96
 *
 */
/******************************************************************************/
/*                                                                            */
/* FUNCTION       Extracts a file from a ZIP archive                          */
/*                                                                            */
/* INPUT          zipfilename                                                 */
/*                file to extract                                             */
/******************************************************************************/

/*
 * $Id: extract.c,v 1.6 1997/09/23 20:07:31 lucifer Release1_2_1 $
 *
 * $Log: extract.c,v $
 * Revision 1.6  1997/09/23 20:07:31  lucifer
 * Removed declaration of strdup
 *
 * Revision 1.5  1997/09/23 17:31:39  lucifer
 * Added option -i
 *
 * Revision 1.4  1997/02/15  09:47:24  lucifer
 * Patch by Mats Lofkvist <mal@aristotle.algonet.se>:
 * Added compile option to *not* convert filenames to uppercase
 *
 * Revision 1.3  1996/08/21 17:52:24  conrad
 * Some more cleanups to suppress warnings
 *
 * Revision 1.2  1996/08/21 17:34:42  conrad
 * cleaned some things up...
 *
 */

#include <stdio.h>
#include <stdlib.h>

#ifndef _WIN32
#include <unistd.h>
#else
#include <io.h>
#endif

#include <fcntl.h>
#include <malloc.h>
#include "headers.h"

static char RCSID[]="$Id: extract.c,v 1.6 1997/09/23 20:07:31 lucifer Release1_2_1 $";

extern char *extract( char *, char *, int caseflg );

#ifndef O_BINARY
#define	O_BINARY	0
#endif

static void usage( char *prg )
{
    fprintf( stderr, "Usage: %s [-i] <zipfile> <file>\n", prg );
    fprintf( stderr, " -i\tswitch off case insensitive filename matching\n" );
}

void main(int argc, char *argv[])
{
char	*ret;
int	outfile, err=0, i=1, caseflg=0;

  if(argc < 3 || argc > 4)
  {
    usage( argv[0] );
    exit(1);
  }
  if( argc == 4 ) {
    if( strcmp( "-i", argv[1] ) ) {
	usage( argv[0] );
	exit(1);
    }
    caseflg = FLG_CASE_SENSITIVE;
    i++;
  }

  /****************************************************************************/
  /* search file and write it to disk                                         */
  /****************************************************************************/
  err = !(ret = extract(argv[i], argv[i+1], caseflg ));

  if( !err )
  {
    outfile = open( argv[i+1], O_CREAT|O_WRONLY|O_BINARY, 0644 );
    if( outfile < 0 )
    {
	fprintf( stderr, "Couldn't open %s!\n", argv[i+1] );
	err = 1;
    }
    else
    {
	if( write( outfile, ret, lh.csize ) != lh.csize )
	{
	    fprintf( stderr, "Couldn't write to %s!\n", argv[i+1] );
	    err = 1;
	}
	close( outfile );
    }
    free( ret );
  }
  exit(err);
}
